==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCellTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCellTypeDescriptionMetadata } from "./WebCellTypeDescriptionMetadata";
import { WebCellTemplateContextDescription } from "./WebCellTemplateContextDescription";
/**
 * @hidden
 */
var WebCellTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCellTemplateContextDescriptionMetadata, _super);
    function WebCellTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCellTemplateContextDescriptionMetadata.b = function (a) {
        if (WebCellTemplateContextDescriptionMetadata.a == null) {
            WebCellTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCellTemplateContextDescriptionMetadata.c(WebCellTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebCellTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCellTemplateContextDescriptionMetadata.a);
        WebCellTypeDescriptionMetadata.d(a);
    };
    WebCellTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CellTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "Unknown");
        a.item("AdditionalTemplateContext", "Unknown");
        a.item("Cell", "ExportedType:WebCellType");
    };
    WebCellTemplateContextDescriptionMetadata.d = function (a) {
        WebCellTemplateContextDescriptionMetadata.b(a);
        a.aa("WebCellTemplateContext", function () { return new WebCellTemplateContextDescription(); });
        a.z("WebCellTemplateContext", WebCellTemplateContextDescriptionMetadata.a);
    };
    WebCellTemplateContextDescriptionMetadata.$t = markType(WebCellTemplateContextDescriptionMetadata, 'WebCellTemplateContextDescriptionMetadata');
    WebCellTemplateContextDescriptionMetadata.a = null;
    return WebCellTemplateContextDescriptionMetadata;
}(Base));
export { WebCellTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCellTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCellTypeDescriptionMetadata } from "./WebCellTypeDescriptionMetadata";
import { WebCellTemplateContextDescription } from "./WebCellTemplateContextDescription";
/**
 * @hidden
 */
var WebCellTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCellTemplateContextDescriptionMetadata, _super);
    function WebCellTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCellTemplateContextDescriptionMetadata.b = function (a) {
        if (WebCellTemplateContextDescriptionMetadata.a == null) {
            WebCellTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCellTemplateContextDescriptionMetadata.c(WebCellTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebCellTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCellTemplateContextDescriptionMetadata.a);
        WebCellTypeDescriptionMetadata.d(a);
    };
    WebCellTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CellTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "Unknown");
        a.item("AdditionalTemplateContext", "Unknown");
        a.item("Cell", "ExportedType:WebCellType");
    };
    WebCellTemplateContextDescriptionMetadata.d = function (a) {
        WebCellTemplateContextDescriptionMetadata.b(a);
        a.ac("WebCellTemplateContext", function () { return new WebCellTemplateContextDescription(); });
        a.ab("WebCellTemplateContext", WebCellTemplateContextDescriptionMetadata.a);
    };
    WebCellTemplateContextDescriptionMetadata.$t = markType(WebCellTemplateContextDescriptionMetadata, 'WebCellTemplateContextDescriptionMetadata');
    WebCellTemplateContextDescriptionMetadata.a = null;
    return WebCellTemplateContextDescriptionMetadata;
}(Base));
export { WebCellTemplateContextDescriptionMetadata };
